@@ -322,31 +322,6 @@ def test_optimized_sync(
     # TODO CHECK IF SYNC WAS NOT OPTIMIZED
 
 
-@pytest.mark.parallel
-def test_semver_sync(
-    ansible_repo_api_client,
-    ansible_collection_version_api_client,
-    ansible_repo_factory,
-    ansible_collection_remote_factory,
-):
-    remote = ansible_collection_remote_factory(
-        url="https://galaxy.ansible.com",
-        requirements_file="collections:\n  - anil_cm.terraform_provider",
-        sync_dependencies=False,
-        signed_only=False,
-    )
-    repository = ansible_repo_factory(remote=remote.pulp_href)
-    monitor_task(ansible_repo_api_client.sync(repository.pulp_href, {}).task)
-    repository = ansible_repo_api_client.read(repository.pulp_href)
-    content = ansible_collection_version_api_client.list(
-        repository_version=repository.latest_version_href
-    )
-    versions = {item.version for item in content.results}
-    # If this fails check that it is still upstream!
-    # TODO create a better local fixture to sync from.
-    assert "0.0.1-rerelease+meta" in versions
-
-
 @pytest.mark.parallel
 def test_last_synced_metadata_time(
     ansible_repo_api_client,
